"use strict";(self.webpackChunk_anaconda_core=self.webpackChunk_anaconda_core||[]).push([[568],{568:(a,n,e)=>{e.r(n),e.d(n,{default:()=>i});var o=e(509),c=e(369);const t=new o.CorePlugin,i={id:"@anaconda/core:plugin",description:"Common Anaconda extension functionality",autoStart:!0,provides:c.tokens.CoreToken,activate:a=>(console.log("JupyterLab extension @anaconda/core is activated!"),t.activate(a),{corePlugin:t})}}}]);